"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.destination_api import DestinationApi  # noqa: E501


class TestDestinationApi(unittest.TestCase):
    """DestinationApi unit test stubs"""

    def setUp(self):
        self.api = DestinationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_destination_api_v1_app_app_id_dest_post(self):
        """Test case for create_destination_api_v1_app_app_id_dest_post

        Create Destination  # noqa: E501
        """
        pass

    def test_delete_destination_api_v1_app_app_id_dest_dest_id_delete(self):
        """Test case for delete_destination_api_v1_app_app_id_dest_dest_id_delete

        Delete Destination  # noqa: E501
        """
        pass

    def test_list_destinations_api_v1_app_app_id_dest_get(self):
        """Test case for list_destinations_api_v1_app_app_id_dest_get

        List Destinations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Svix

    The Svix server API documentation  # noqa: E501

    The version of the OpenAPI document: 1.4
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from svix.openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from svix.openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from svix.openapi_client.model.http_validation_error import HTTPValidationError
from svix.openapi_client.model.http_error_out import HttpErrorOut
from svix.openapi_client.model.list_response_endpoint_message_out import ListResponseEndpointMessageOut
from svix.openapi_client.model.list_response_message_attempt_endpoint_out import ListResponseMessageAttemptEndpointOut
from svix.openapi_client.model.list_response_message_attempt_out import ListResponseMessageAttemptOut
from svix.openapi_client.model.list_response_message_endpoint_out import ListResponseMessageEndpointOut
from svix.openapi_client.model.message_attempt_out import MessageAttemptOut
from svix.openapi_client.model.message_status import MessageStatus


class MessageAttemptApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get(
            self,
            attempt_id,
            msg_id,
            app_id,
            **kwargs
        ):
            """Get Attempt  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get(attempt_id, msg_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                attempt_id (str):
                msg_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MessageAttemptOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['attempt_id'] = \
                attempt_id
            kwargs['msg_id'] = \
                msg_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get = _Endpoint(
            settings={
                'response_type': (MessageAttemptOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/msg/{msg_id}/attempt/{attempt_id}/',
                'operation_id': 'get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'attempt_id',
                    'msg_id',
                    'app_id',
                ],
                'required': [
                    'attempt_id',
                    'msg_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'attempt_id':
                        (str,),
                    'msg_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'attempt_id': 'attempt_id',
                    'msg_id': 'msg_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'attempt_id': 'path',
                    'msg_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get
        )

        def __list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get(
            self,
            msg_id,
            app_id,
            **kwargs
        ):
            """List Attempted Destinations  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get(msg_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                msg_id (str):
                app_id (str):

            Keyword Args:
                iterator (str): [optional]
                limit (int): [optional] if omitted the server will use the default value of 50
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListResponseMessageEndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['msg_id'] = \
                msg_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get = _Endpoint(
            settings={
                'response_type': (ListResponseMessageEndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/msg/{msg_id}/endpoint/',
                'operation_id': 'list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'msg_id',
                    'app_id',
                    'iterator',
                    'limit',
                ],
                'required': [
                    'msg_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'msg_id':
                        (str,),
                    'app_id':
                        (str,),
                    'iterator':
                        (str,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'msg_id': 'msg_id',
                    'app_id': 'app_id',
                    'iterator': 'iterator',
                    'limit': 'limit',
                },
                'location_map': {
                    'msg_id': 'path',
                    'app_id': 'path',
                    'iterator': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get
        )

        def __list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get(
            self,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """List Attempted Messages  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get(endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                iterator (str): [optional]
                limit (int): [optional] if omitted the server will use the default value of 50
                status (MessageStatus): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListResponseEndpointMessageOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get = _Endpoint(
            settings={
                'response_type': (ListResponseEndpointMessageOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/msg/',
                'operation_id': 'list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                    'iterator',
                    'limit',
                    'status',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                    'iterator':
                        (str,),
                    'limit':
                        (int,),
                    'status':
                        (MessageStatus,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                    'iterator': 'iterator',
                    'limit': 'limit',
                    'status': 'status',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                    'iterator': 'query',
                    'limit': 'query',
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get
        )

        def __list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get(
            self,
            msg_id,
            app_id,
            **kwargs
        ):
            """List Attempts  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get(msg_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                msg_id (str):
                app_id (str):

            Keyword Args:
                iterator (str): [optional]
                limit (int): [optional] if omitted the server will use the default value of 50
                status (MessageStatus): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListResponseMessageAttemptOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['msg_id'] = \
                msg_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get = _Endpoint(
            settings={
                'response_type': (ListResponseMessageAttemptOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/msg/{msg_id}/attempt/',
                'operation_id': 'list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'msg_id',
                    'app_id',
                    'iterator',
                    'limit',
                    'status',
                ],
                'required': [
                    'msg_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'msg_id':
                        (str,),
                    'app_id':
                        (str,),
                    'iterator':
                        (str,),
                    'limit':
                        (int,),
                    'status':
                        (MessageStatus,),
                },
                'attribute_map': {
                    'msg_id': 'msg_id',
                    'app_id': 'app_id',
                    'iterator': 'iterator',
                    'limit': 'limit',
                    'status': 'status',
                },
                'location_map': {
                    'msg_id': 'path',
                    'app_id': 'path',
                    'iterator': 'query',
                    'limit': 'query',
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_attempts_api_v1_app_app_id_msg_msg_id_attempt_get
        )

        def __list_attempts_for_endpoint_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_attempt_get(
            self,
            msg_id,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """List Attempts For Endpoint  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_attempts_for_endpoint_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_attempt_get(msg_id, endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                msg_id (str):
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                iterator (str): [optional]
                limit (int): [optional] if omitted the server will use the default value of 50
                status (MessageStatus): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListResponseMessageAttemptEndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['msg_id'] = \
                msg_id
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.list_attempts_for_endpoint_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_attempt_get = _Endpoint(
            settings={
                'response_type': (ListResponseMessageAttemptEndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/msg/{msg_id}/endpoint/{endpoint_id}/attempt/',
                'operation_id': 'list_attempts_for_endpoint_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_attempt_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'msg_id',
                    'endpoint_id',
                    'app_id',
                    'iterator',
                    'limit',
                    'status',
                ],
                'required': [
                    'msg_id',
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'msg_id':
                        (str,),
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                    'iterator':
                        (str,),
                    'limit':
                        (int,),
                    'status':
                        (MessageStatus,),
                },
                'attribute_map': {
                    'msg_id': 'msg_id',
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                    'iterator': 'iterator',
                    'limit': 'limit',
                    'status': 'status',
                },
                'location_map': {
                    'msg_id': 'path',
                    'endpoint_id': 'path',
                    'app_id': 'path',
                    'iterator': 'query',
                    'limit': 'query',
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_attempts_for_endpoint_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_attempt_get
        )

        def __resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post(
            self,
            endpoint_id,
            msg_id,
            app_id,
            **kwargs
        ):
            """Resend Webhook  # noqa: E501

            Resend a message to the specified endpoint.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post(endpoint_id, msg_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                msg_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['msg_id'] = \
                msg_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/msg/{msg_id}/endpoint/{endpoint_id}/resend/',
                'operation_id': 'resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'msg_id',
                    'app_id',
                ],
                'required': [
                    'endpoint_id',
                    'msg_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'msg_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'msg_id': 'msg_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'msg_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post
        )



# flake8: noqa

"""
    Svix

    The Svix server API documentation  # noqa: E501

    The version of the OpenAPI document: 1.4
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from svix.openapi_client.api_client import ApiClient

# import Configuration
from svix.openapi_client.configuration import Configuration

# import exceptions
from svix.openapi_client.exceptions import OpenApiException
from svix.openapi_client.exceptions import ApiAttributeError
from svix.openapi_client.exceptions import ApiTypeError
from svix.openapi_client.exceptions import ApiValueError
from svix.openapi_client.exceptions import ApiKeyError
from svix.openapi_client.exceptions import ApiException



"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_dashboard_access_api_v1_auth_dashboard_access_app_id_post(self):
        """Test case for get_dashboard_access_api_v1_auth_dashboard_access_app_id_post

        Get Dashboard Access  # noqa: E501
        """
        pass

    def test_logout_api_v1_auth_logout_post(self):
        """Test case for logout_api_v1_auth_logout_post

        Logout  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.application_api import ApplicationApi  # noqa: E501


class TestApplicationApi(unittest.TestCase):
    """ApplicationApi unit test stubs"""

    def setUp(self):
        self.api = ApplicationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_application_api_v1_app_post(self):
        """Test case for create_application_api_v1_app_post

        Create Application  # noqa: E501
        """
        pass

    def test_delete_application_api_v1_app_app_id_delete(self):
        """Test case for delete_application_api_v1_app_app_id_delete

        Delete Application  # noqa: E501
        """
        pass

    def test_list_applications_api_v1_app_get(self):
        """Test case for list_applications_api_v1_app_get

        List Applications  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import diahook.openapi_client
from diahook.openapi_client.model.event_type_in_out import EventTypeInOut


class TestEventTypeInOut(unittest.TestCase):
    """EventTypeInOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEventTypeInOut(self):
        """Test EventTypeInOut"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EventTypeInOut()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.endpoint_api import EndpointApi  # noqa: E501


class TestEndpointApi(unittest.TestCase):
    """EndpointApi unit test stubs"""

    def setUp(self):
        self.api = EndpointApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_endpoint_api_v1_app_app_id_endpoint_post(self):
        """Test case for create_endpoint_api_v1_app_app_id_endpoint_post

        Create Endpoint  # noqa: E501
        """
        pass

    def test_delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete(self):
        """Test case for delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete

        Delete Endpoint  # noqa: E501
        """
        pass

    def test_get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get(self):
        """Test case for get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get

        Get Endpoint  # noqa: E501
        """
        pass

    def test_get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get(self):
        """Test case for get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get

        Get Endpoint Secret  # noqa: E501
        """
        pass

    def test_list_endpoints_api_v1_app_app_id_endpoint_get(self):
        """Test case for list_endpoints_api_v1_app_app_id_endpoint_get

        List Endpoints  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.message_api import MessageApi  # noqa: E501


class TestMessageApi(unittest.TestCase):
    """MessageApi unit test stubs"""

    def setUp(self):
        self.api = MessageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message_api_v1_app_app_id_msg_post(self):
        """Test case for create_message_api_v1_app_app_id_msg_post

        Create Message  # noqa: E501
        """
        pass

    def test_get_message_api_v1_app_app_id_msg_msg_id_get(self):
        """Test case for get_message_api_v1_app_app_id_msg_msg_id_get

        Get Message  # noqa: E501
        """
        pass

    def test_list_messages_api_v1_app_app_id_msg_get(self):
        """Test case for list_messages_api_v1_app_app_id_msg_get

        List Messages  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import whsaas.openapi_client
from whsaas.openapi_client.model.message_in import MessageIn


class TestMessageIn(unittest.TestCase):
    """MessageIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessageIn(self):
        """Test MessageIn"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MessageIn()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import diahook.openapi_client
from diahook.openapi_client.model.message_status import MessageStatus
globals()['MessageStatus'] = MessageStatus
from diahook.openapi_client.model.endpoint_message_out import EndpointMessageOut


class TestEndpointMessageOut(unittest.TestCase):
    """EndpointMessageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointMessageOut(self):
        """Test EndpointMessageOut"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointMessageOut()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.event_type_api import EventTypeApi  # noqa: E501


class TestEventTypeApi(unittest.TestCase):
    """EventTypeApi unit test stubs"""

    def setUp(self):
        self.api = EventTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_event_type_api_v1_event_type_post(self):
        """Test case for create_event_type_api_v1_event_type_post

        Create Event Type  # noqa: E501
        """
        pass

    def test_delete_event_type_api_v1_event_type_event_type_name_delete(self):
        """Test case for delete_event_type_api_v1_event_type_event_type_name_delete

        Delete Event Type  # noqa: E501
        """
        pass

    def test_list_event_types_api_v1_event_type_get(self):
        """Test case for list_event_types_api_v1_event_type_get

        List Event Types  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from .receiver import Webhook  # noqa
from .api import (
    Svix,
    SvixOptions,
    FetchOptions,
    DashboardAccessOut,
    MessageIn,
    MessageOut,
    ListResponseMessageOut,
    ApplicationIn,
    ApplicationOut,
    ListResponseApplicationOut,
)  # noqa



"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.message_attempt_api import MessageAttemptApi  # noqa: E501


class TestMessageAttemptApi(unittest.TestCase):
    """MessageAttemptApi unit test stubs"""

    def setUp(self):
        self.api = MessageAttemptApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_attempt_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_attempt_id_get(self):
        """Test case for get_attempt_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_attempt_id_get

        Get Attempt  # noqa: E501
        """
        pass

    def test_list_attempted_destinations_api_v1_app_app_id_msg_msg_id_dest_get(self):
        """Test case for list_attempted_destinations_api_v1_app_app_id_msg_msg_id_dest_get

        List Attempted Destinations  # noqa: E501
        """
        pass

    def test_list_attempts_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_get(self):
        """Test case for list_attempts_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_get

        List Attempts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Svix

    The Svix server API documentation  # noqa: E501

    The version of the OpenAPI document: 1.4
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from svix.openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from svix.openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from svix.openapi_client.model.endpoint_in import EndpointIn
from svix.openapi_client.model.endpoint_out import EndpointOut
from svix.openapi_client.model.endpoint_secret import EndpointSecret
from svix.openapi_client.model.endpoint_stats import EndpointStats
from svix.openapi_client.model.http_validation_error import HTTPValidationError
from svix.openapi_client.model.http_error_out import HttpErrorOut
from svix.openapi_client.model.list_response_endpoint_out import ListResponseEndpointOut


class EndpointApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_endpoint_api_v1_app_app_id_endpoint_post(
            self,
            app_id,
            endpoint_in,
            **kwargs
        ):
            """Create Endpoint  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_endpoint_api_v1_app_app_id_endpoint_post(app_id, endpoint_in, async_req=True)
            >>> result = thread.get()

            Args:
                app_id (str):
                endpoint_in (EndpointIn):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['app_id'] = \
                app_id
            kwargs['endpoint_in'] = \
                endpoint_in
            return self.call_with_http_info(**kwargs)

        self.create_endpoint_api_v1_app_app_id_endpoint_post = _Endpoint(
            settings={
                'response_type': (EndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/',
                'operation_id': 'create_endpoint_api_v1_app_app_id_endpoint_post',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'app_id',
                    'endpoint_in',
                ],
                'required': [
                    'app_id',
                    'endpoint_in',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'app_id':
                        (str,),
                    'endpoint_in':
                        (EndpointIn,),
                },
                'attribute_map': {
                    'app_id': 'app_id',
                },
                'location_map': {
                    'app_id': 'path',
                    'endpoint_in': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_endpoint_api_v1_app_app_id_endpoint_post
        )

        def __delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete(
            self,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """Delete Endpoint  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete(endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/',
                'operation_id': 'delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete
        )

        def __get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get(
            self,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """Get Endpoint  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get(endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get = _Endpoint(
            settings={
                'response_type': (EndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/',
                'operation_id': 'get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get
        )

        def __get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get(
            self,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """Get Endpoint Secret  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get(endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EndpointSecret
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get = _Endpoint(
            settings={
                'response_type': (EndpointSecret,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/secret/',
                'operation_id': 'get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get
        )

        def __get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get(
            self,
            endpoint_id,
            app_id,
            **kwargs
        ):
            """Get Endpoint Stats  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get(endpoint_id, app_id, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EndpointStats
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get = _Endpoint(
            settings={
                'response_type': (EndpointStats,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/stats/',
                'operation_id': 'get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get
        )

        def __list_endpoints_api_v1_app_app_id_endpoint_get(
            self,
            app_id,
            **kwargs
        ):
            """List Endpoints  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_endpoints_api_v1_app_app_id_endpoint_get(app_id, async_req=True)
            >>> result = thread.get()

            Args:
                app_id (str):

            Keyword Args:
                iterator (str): [optional]
                limit (int): [optional] if omitted the server will use the default value of 50
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListResponseEndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['app_id'] = \
                app_id
            return self.call_with_http_info(**kwargs)

        self.list_endpoints_api_v1_app_app_id_endpoint_get = _Endpoint(
            settings={
                'response_type': (ListResponseEndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/',
                'operation_id': 'list_endpoints_api_v1_app_app_id_endpoint_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'app_id',
                    'iterator',
                    'limit',
                ],
                'required': [
                    'app_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'app_id':
                        (str,),
                    'iterator':
                        (str,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'app_id': 'app_id',
                    'iterator': 'iterator',
                    'limit': 'limit',
                },
                'location_map': {
                    'app_id': 'path',
                    'iterator': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_endpoints_api_v1_app_app_id_endpoint_get
        )

        def __update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put(
            self,
            endpoint_id,
            app_id,
            endpoint_in,
            **kwargs
        ):
            """Update Endpoint  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put(endpoint_id, app_id, endpoint_in, async_req=True)
            >>> result = thread.get()

            Args:
                endpoint_id (str):
                app_id (str):
                endpoint_in (EndpointIn):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EndpointOut
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['endpoint_id'] = \
                endpoint_id
            kwargs['app_id'] = \
                app_id
            kwargs['endpoint_in'] = \
                endpoint_in
            return self.call_with_http_info(**kwargs)

        self.update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put = _Endpoint(
            settings={
                'response_type': (EndpointOut,),
                'auth': [
                    'HTTPBearer'
                ],
                'endpoint_path': '/api/v1/app/{app_id}/endpoint/{endpoint_id}/',
                'operation_id': 'update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'endpoint_id',
                    'app_id',
                    'endpoint_in',
                ],
                'required': [
                    'endpoint_id',
                    'app_id',
                    'endpoint_in',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'endpoint_id':
                        (str,),
                    'app_id':
                        (str,),
                    'endpoint_in':
                        (EndpointIn,),
                },
                'attribute_map': {
                    'endpoint_id': 'endpoint_id',
                    'app_id': 'app_id',
                },
                'location_map': {
                    'endpoint_id': 'path',
                    'app_id': 'path',
                    'endpoint_in': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put
        )



"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.health_api import HealthApi  # noqa: E501


class TestHealthApi(unittest.TestCase):
    """HealthApi unit test stubs"""

    def setUp(self):
        self.api = HealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_health_api_v1_health_get(self):
        """Test case for health_api_v1_health_get

        Health  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
